@@ -2,7 +2,7 @@ import sys
 import typing as t
 
 
-def get_annotated_type(cls, field, default=None) -> t.Optional[t.Type]:
+def get_annotated_type(cls, field, default=None) -> t.Any:
     annotations = t.get_type_hints(cls)
     return annotations.get(field, default)
 
